#!/bin/sh

basedir=`pwd`

user=tipadmin
passwd=tippass
if [ ! -z "$1" ]; then
	user=$1
fi
if [ ! -z "$2" ]; then
	passwd=$2
fi
base="7.3.0"
fixpack="3"
full="${base}.${fixpack}"

echo "Searching for installed components..."

de=""
for dir in $SI_PATH/bin $HOME/.acsi_$USER/bin /usr/ibm/common/acsi/bin
do
	if [ -x $dir/de_lsrootiu.sh ]; then
		de=$dir
		break
	fi
done
if [ -z "$de" ]; then
	echo "Unable to find DE"
	exit 1
fi

patched=0
$de/de_lsrootiu.sh | grep "IU,TUAM_" | sort | (while read line
do
	oifs="$IFS"
	IFS=","
	set `echo "$line" | awk -F, '{print $2 "," $4 "," $5 "," $6}' | sed 's/]<.*//'`
	IFS="$oifs"
	component=$1
	version=$2
	disc=$3
	uuid=$4
	installedbase=`echo $version | awk -F. '{print $1 "." $2 "." $3}'`
	installedfp=`echo $version | awk -F. '{print $NF}'`
	if [ "$installedbase" == "$base" ] && [ "$installedfp" -lt "$fixpack" ] && [ -d $basedir/$component/META-INF ]; then
		echo "Applying patch for $component"
		cd $basedir/$component/META-INF
		. $disc/bin/setupEnv.sh
		if [ "$component" == "TUAM_UI" ]; then
			cat > var.properties <<EOF
Variable#RootIUTypeID[${uuid},${full}]#IAGLOBAL_TIP_HOME=${TIP_HOME}
Variable#RootIUTypeID[${uuid},${full}]#shExt=sh
Variable#RootIUTypeID[${uuid},${full}]#IAGLOBAL_WASUserID=$user
Variable#RootIUTypeID[${uuid},${full}]#IALOCAL_WASPassword=$passwd
EOF
			$de/manageIU.sh -o update -u true -i var.properties -r $TUAM_HOME -p packagedIU.xml >> $TUAM_HOME/logs/fp_${component}.log 2>&1
			rm -f var.properties
		else
			$de/manageIU.sh -o update -r $TUAM_HOME -p packagedIU.xml -u true >> $TUAM_HOME/logs/fp_${component}.log 2>&1
		fi
		if [ $? -ne 0 ]; then
			echo "Patch failed"
			exit 1
		fi
		mkdir -p $TUAM_HOME/_uninst/fixes/fp${fixpack}/$component
		cp * $TUAM_HOME/_uninst/fixes/fp${fixpack}/$component
		patched=1
	fi
done
if [ $patched -eq 0 ]; then
   echo "TUAM Release ${base}.0 to ${base}.`expr $fixpack - 1` must be installed to install this fix pack."
   echo "Please install this version before attempting to install this fix pack."
   echo "Fix has not been applied successfully."
   exit 1
fi
)

