#!/bin/sh
#   *************************************************************** {COPYRIGHT-TOP}
#   * Licensed Materials - Property of IBM
#   * Restricted Materials of IBM
#   * IBM Tivoli Usage and Accounting Manager
#   * 5724-O33, 5765-UAV, 5765-UA7, 44E7863
#   * (c) Copyright IBM Corp. 2004, 2007 All Rights Reserved.
#   *
#   * US Government Users Restricted Rights - Use, duplication or
#   * disclosure restricted by GSA ADP Schedule Contract with
#   * IBM Corp.
#   **************************************************************** {COPYRIGHT-END}
#
#   ****************************************************************
#   * TUAM deploy/undeploy/redeploy Installation Script
#   *
#   *    If WAS security is enabled, then a username and password are
#   *    required to stop the server.  If security is disabled, then
#   *    any supplied user and password are ignored by WAS.
#   *
#   * Usage: deployTuam.sh  install | remove | replace [user] [password]
#   ****************************************************************

#
# Setup Global Commands, Resources, and Variables
#
INTERP=`uname -s`
RELEASE=`uname -r`
ECHO="echo"

. `dirname $0`/../../bin/setupEnv.sh

error()
{
   echo deployTuam failed!  Exiting with error: $RETCODE
   exit $RETCODE
}

#
# Setup Interp Specific Commands, Resources, and Variables
#
if [ "${INTERP}" = "Linux" ]; then
   ECHO="echo -e"
   if [ -f /etc/redhat-release ]; then
      DISTRO=Redhat
   elif [ -f /etc/suse-release ]; then
      DISTRO=SuSE
   fi
fi

PROFILE=TIPProfile
USER=default
PASSWORD=default

USAGE="Usage:\n\
       \tdeployTuam.sh install [user] [password]\n\
       \tdeployTuam.sh remove  [user] [password]\n\
       \tdeployTuam.sh replace [user] [password]"


if [ -n "${1}" ]; then

   if [ -n "${2}" ]; then
      USER=${2}
   fi

   if [ -n "${3}" ]; then
      PASSWORD=${3}
   fi

   if [ "${1}" = "replace" ] || [ "${1}" = "remove" ]; then
      #
      # Remove
      #      

      cd ${TIP_HOME}/profiles/${PROFILE}/bin
      ./wsadmin.sh -f ${TUAM_HOME}/setup/console/deployTUAMConsole.py remove -user "${USER}" -password "${PASSWORD}"
      RETCODE=$?
      if [ "$RETCODE" -ne "0" ]; then
         error
      fi     
   
   fi
   if [ "${1}" = "install" ] || [ "${1}" = "replace" ]; then
      #
      # Install
      #
            
      cd ${TUAM_HOME}/setup/console
      cp ${TUAM_HOME}/setup/console/aucConsole.war ${TIP_HOME}/profiles/${PROFILE}/installedApps/TIPCell/isc.ear/aucConsole.war
      RETCODE=$?
      if [ "$RETCODE" -ne "0" ]; then
         error
      fi

	  cd ${TUAM_HOME}
      ${TIP_HOME}/profiles/${PROFILE}/bin/wsadmin.sh -f ${TUAM_HOME}/setup/console/deployTUAMConsole.py install lib -user "${USER}" -password "${PASSWORD}"
      RETCODE=$?
      if [ "$RETCODE" -ne "0" ]; then
         error
      fi
	  
	  ${TIP_HOME}/profiles/${PROFILE}/bin/wsadmin.sh -lang jython -f ${TUAM_HOME}/setup/console/addSharedLibToWar.py -user "${USER}" -password "${PASSWORD}"
      RETCODE=$?
      if [ "$RETCODE" -ne "0" ]; then
         error
      fi

   fi
   
   if [ "${1}" != "install" ] && [ "${1}" != "replace" ] && [ "${1}" != "remove" ] ; then
      #
      # Invalid option
      #
      ${ECHO} "\"${1}\" is an invalid option"
      ${ECHO} ${USAGE}
      exit 2

   fi

else
   ${ECHO} ${USAGE}
   exit 1
fi





