#!/bin/sh

basedir=`pwd`

user=tipadmin
passwd=tippass
if [ ! -z "$1" ]; then
	user=$1
fi
if [ ! -z "$2" ]; then
	passwd=$2
fi

echo "Searching for installed components..."

de=""
for dir in $SI_PATH/bin $HOME/.acsi_$USER/bin /usr/ibm/common/acsi/bin
do
	if [ -x $dir/de_lsrootiu.sh ]; then
		de=$dir
		break
	fi
done
if [ -z "$de" ]; then
	echo "Unable to find DE"
	exit 1
fi

patched=0
$de/de_lsrootiu.sh | grep "IU,TUAM_" | sort | (while read line
do
	oifs="$IFS"
    IFS=","
	set `echo "$line" | awk -F, '{print $2 "," $4 "," $5 "," $6}' | sed 's/]<.*//'`
	IFS="$oifs"
	component=$1
	version=$2
	disc=$3
	uuid=$4
	[ -x $disc/bin/setupEnv.sh ] && . $disc/bin/setupEnv.sh
	if [ "$version" == "7.3.0.3" ] && [ -d $TUAM_HOME/_uninst/fixes/fp3/$component ]; then
		echo "Undoing patch for $component"
		cd $TUAM_HOME/_uninst/fixes/fp3/$component
		if [ "$component" == "TUAM_UI" ]; then
			# As the non-fixpack deploy script doesn't redeploy collector jars, we want to keep the
			# fixpack one around until we have redeployed the original 7.3.0 war.
			cp $TUAM_HOME/setup/console/deployTuam.sh $TUAM_HOME/setup/console/deployTuam_fp1.sh
			cp $TUAM_HOME/setup/console/deployTUAMConsole.py $TUAM_HOME/setup/console/deployTUAMConsole_fp1.py
			cat > var.properties <<EOF
Variable#RootIUTypeID[${uuid},7.3.0.3]#IAGLOBAL_TIP_HOME=${TIP_HOME}
Variable#RootIUTypeID[${uuid},7.3.0.3]#shExt=sh
EOF
			$de/manageIU.sh -o undo -i var.properties -r $TUAM_HOME -p packagedIU.xml >> $TUAM_HOME/logs/fp_${component}.log 2>&1
			status=$?
			rm -f var.properties
			if [ $status -eq 0 ]; then
				mv $TUAM_HOME/setup/console/deployTUAMConsole.py $TUAM_HOME/setup/console/deployTUAMConsole_fp0.py
				mv $TUAM_HOME/setup/console/deployTUAMConsole_fp1.py $TUAM_HOME/setup/console/deployTUAMConsole.py
				chmod a+x $TUAM_HOME/setup/console/deployTuam*.sh
				$TUAM_HOME/setup/console/deployTuam_fp1.sh replace $user $passwd >> $TUAM_HOME/logs/fp_${component}.log 2>&1
				status=$?
				mv $TUAM_HOME/setup/console/deployTUAMConsole_fp0.py $TUAM_HOME/setup/console/deployTUAMConsole.py
			else
				rm -f $TUAM_HOME/setup/console/deployTUAMConsole_fp1.py
			fi
			rm -f $TUAM_HOME/setup/console/deployTuam_fp1.sh
		else
			$de/manageIU.sh -o undo -r $TUAM_HOME -p packagedIU.xml >> $TUAM_HOME/logs/fp_${component}.log 2>&1
			status=$?
		fi
		if [ $status -ne 0 ]; then
			echo "Undo failed"
			exit 1
		else
			rm -rf $TUAM_HOME/_uninst/fixes/fp3/$component
		fi
		patched=1
	fi
done
if [ $patched -eq 0 ]; then
   echo "TUAM Release 7.3.0.3 must be installed to remove this fix pack."
   echo "Please install this version before attempting to remove this fix pack."
   echo "Fix has not been unapplied successfully."
   exit 1
fi
)
